@@ -36,7 +36,7 @@
 
 # preliminaries
 TEXTDOMAINDIR=/usr/share/locale
-TEXTDOMAIN=unplugdrive.sh
+TEXTDOMAIN=unplugdrive
 
 title=$"Unplug USB device"
 version="0.83"
